=======
Credits
=======

Development Lead
----------------

* Dorian Turba <contact.r9qrp@8shield.net>

Original Author
------------

Simon Desnoe <0d3s3n@gmail.com>

Contributors
------------

None yet. Why not be the first?
